# Copyright (c) 2000-2005, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
%global version_str %(sed -e 's/\\./-/g' <<<"%{version}")
%global version_major_minor %(sed -e 's/\\([0-9]*\\.[0-9]*\\)\\..*/\\1/g' <<<"%{version}")
%global version_major_minor_str %(sed -e 's/\\./-/g' <<<"%{version_major_minor}")
%global version_maven %(sed -e 's/\\(.*\\)\\.\\([0-9]*\\)/\\1-\\2/g' <<<"%{version}")
%global artifact_id Saxon-HE
Summary:        Java XPath, XSLT 2.0 and XQuery implementation
Name:           saxon
Version:        9.4.0.9
Release:        %mkrel 1
Group:          Development/Java
# net.sf.saxon.om.XMLChar is from ASL-licensed Xerces
# net/sf/saxon/option/jdom/ is MPLv1.1
# net/sf/saxon/serialize/codenorm/ is UCD
# net/sf/saxon/expr/sort/GenericSorter.java is MIT
# net/sf/saxon/expr/Tokenizer.java and few other bits are BSD
License:        MPLv1.0 and MPLv1.1 and ASL 1.1 and UCD and MIT
URL:            http://saxon.sourceforge.net/
Source0:        https://downloads.sourceforge.net/project/saxon/Saxon-HE/%{version_major_minor}/saxon%{version_str}source.zip
Source1:        %{name}.saxon.script
Source2:        %{name}.saxonq.script
Source3:        %{name}.build.script
Source4:        %{name}.1
Source5:        %{name}q.1
Source6:        https://downloads.sourceforge.net/project/saxon/Saxon-HE/%{version_major_minor}/saxon-resources%{version_major_minor_str}.zip
Source8:        http://www.mozilla.org/MPL/1.0/index.txt#/mpl-1.0.txt
Source9:        http://www.mozilla.org/MPL/1.0/index.txt#/mpl-1.1.txt
BuildRequires:  unzip
BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  ant
BuildRequires:  javapackages-local
BuildRequires:  bea-stax-api
BuildRequires:  xml-commons-apis
BuildRequires:  xml-commons-resolver
BuildRequires:  xom
BuildRequires:  java-javadoc
BuildRequires:  jdom >= 0:1.0-0.b7
BuildRequires:  jdom-javadoc >= 0:1.0-0.b9.3jpp
BuildRequires:  jdom2
BuildRequires:  dom4j
Requires:       bea-stax-api
Requires:       bea-stax
Requires:       chkconfig
Provides:       jaxp_transform_impl = %{version}-%{release}

# Older versions were split into multile packages
Obsoletes:  %{name}-xpath < %{version}-%{release}
Provides:   %{name}-xpath = %{version}-%{release}
Obsoletes:  %{name}-xom < %{version}-%{release}
Provides:   %{name}-xom = %{version}-%{release}
Obsoletes:  %{name}-sql < %{version}-%{release}
Provides:   %{name}-sql = %{version}-%{release}
Obsoletes:  %{name}-jdom < %{version}-%{release}
Provides:   %{name}-jdom = %{version}-%{release}
Obsoletes:  %{name}-dom < %{version}-%{release}
Provides:   %{name}-dom = %{version}-%{release}

BuildArch:      noarch

%description
Saxon HE is Saxonica's non-schema-aware implementation of the XPath 2.0,
XSLT 2.0, and XQuery 1.0 specifications aligned with the W3C Candidate
Recommendation published on 3 November 2005. It is a complete and
conformant implementation, providing all the mandatory features of
those specifications and nearly all the optional features.

%package        manual
Summary:        Manual for %{name}

%description    manual
Manual for %{name}.

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
Javadoc for %{name}.

%package        demo
Summary:        Demos for %{name}
Requires:       %{name} = %{version}-%{release}

%description    demo
Demonstrations and samples for %{name}.

%package        scripts
Summary:        Utility scripts for %{name}
Requires:       %{name} = %{version}-%{release}

%description    scripts
Utility scripts for %{name}.


%prep
%setup -q -c

unzip -q %{SOURCE6}
cp -p %{SOURCE3} ./build.xml

# deadNET
rm -rf net/sf/saxon/dotnet samples/cs

# Depends on XQJ (javax.xml.xquery)
rm -rf net/sf/saxon/xqj

# This requires a EE edition feature (com.saxonica.xsltextn)
rm -rf net/sf/saxon/option/sql/SQLElementFactory.java

# cleanup unnecessary stuff we'll build ourselves
rm -rf docs/api
find . \( -name "*.jar" -name "*.pyc" \) -delete

cp %{SOURCE8} %{SOURCE9} .

cat >%{artifact_id}-%{version_maven}.pom <<POM_XML
<?xml version="1.0" encoding="UTF-8"?>
<project xmlns="http://maven.apache.org/POM/4.0.0" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://maven.apache.org/POM/4.0.0 http://maven.apache.org/maven-v4_0_0.xsd">

  <modelVersion>4.0.0</modelVersion>
  <groupId>net.sf.saxon</groupId>
  <artifactId>%{artifact_id}</artifactId>
  <version>%{version_maven}</version>
  <packaging>jar</packaging>
  <name>%{artifact_id}</name>
  <url>http://saxon.sf.net/</url>
  <description>The XSLT and XQuery Processor</description>
  <licenses>
    <license>
      <name>Mozilla Public License Version 2.0</name>
      <url>http://www.mozilla.org/MPL/2.0/</url>
      <distribution>repo</distribution>
    </license>
  </licenses>

  <scm>
    <connection>scm:svn:https://dev.saxonica.com/repos/archive/opensource/latest%{version_major_minor}/</connection>
    <developerConnection>scm:svn:https://dev.saxonica.com/repos/archive/opensource/latest%{version_major_minor}/</developerConnection>
    <url>https://saxon.svn.sourceforge.net/svnroot/saxon/latest%{version_major_minor}/</url>
  </scm>
</project> 
POM_XML

%build
mkdir -p build/classes
cat >build/classes/edition.properties <<EOF
config=net.sf.saxon.Configuration
platform=net.sf.saxon.java.JavaPlatform
EOF

export CLASSPATH=%(build-classpath axiom xml-commons-apis xml-commons-resolver jdom jdom2 xom bea-stax-api dom4j)
ant \
  -Dj2se.javadoc=%{_javadocdir}/java \
  -Djdom.javadoc=%{_javadocdir}/jdom

%mvn_artifact %{artifact_id}-%{version_maven}.pom build/lib/saxon.jar
%mvn_alias : :saxon
%mvn_alias : net.sf.saxon:saxon::dom:

%install
%mvn_install

# For compactability
ln -s %{artifact_id}.jar $RPM_BUILD_ROOT/%{_javadir}/saxon/saxon.jar

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}
cp -pr build/api/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}

# demo
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}
cp -pr samples/* $RPM_BUILD_ROOT%{_datadir}/%{name}

# scripts
mkdir -p $RPM_BUILD_ROOT%{_bindir}
install -p -m755 %{SOURCE1} $RPM_BUILD_ROOT%{_bindir}/%{name}
install -p -m755 %{SOURCE2} $RPM_BUILD_ROOT%{_bindir}/%{name}q
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
install -p -m644 %{SOURCE4} $RPM_BUILD_ROOT%{_mandir}/man1/%{name}.1
install -p -m644 %{SOURCE5} $RPM_BUILD_ROOT%{_mandir}/man1/%{name}q.1

# jaxp_transform_impl ghost symlink
ln -s %{_sysconfdir}/alternatives \
  $RPM_BUILD_ROOT%{_javadir}/jaxp_transform_impl.jar

%post
update-alternatives --install %{_javadir}/jaxp_transform_impl.jar \
  jaxp_transform_impl %{_javadir}/saxon/%{artifact_id}.jar 25

%preun
{
  [ $1 -eq 0 ] || exit 0
  update-alternatives --remove jaxp_transform_impl %{_javadir}/saxon/saxon.jar \
  || update-alternatives --remove jaxp_transform_impl %{_javadir}/saxon/%{artifact_id}.jar
} >/dev/null 2>&1 || :

%files -f .mfiles
%license mpl-1.0.txt mpl-1.1.txt
%{_javadir}/%{name}/saxon.jar
%ghost %{_javadir}/jaxp_transform_impl.jar

%files manual
%doc doc/*

%files javadoc
%doc mpl-1.0.txt mpl-1.1.txt
%{_javadocdir}/%{name}

%files demo
%{_datadir}/%{name}

%files scripts
%{_bindir}/%{name}
%{_bindir}/%{name}q
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}q.1*





%changelog
* Tue May 10 2016 daviddavid <daviddavid> 9.4.0.9-1.mga6
+ Revision: 1012203
- Upstream update to 9.4.0-9
- Remove Source7: saxon-{version}.pom, use here-document to generate it.
- pom:
    artifactId: Saxon-HE
    filename: {artifact_id}-{version_maven}.pom (i.e Saxon-HE-9.4.0-9.pom)
    saxon-{version_maven} is provided by mvn_alias
- Move license file under license tag.

  + neoclust <neoclust>
    - Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 9.3.0.4-17.mga6
+ Revision: 978151
- First rebuild of the java stack
- sync package saxon with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Tue Jan 13 2015 daviddavid <daviddavid> 9.3.0.4-14.mga5
+ Revision: 810389
- Sync more with fc21 to add back artifact net.sf.saxon:saxon

* Mon Jan 12 2015 daviddavid <daviddavid> 9.3.0.4-13.mga5
+ Revision: 810155
- Sync with fc21
- use '%%mvn_install -J' macro for install javadoc too
- fix Group

* Wed Oct 15 2014 umeabot <umeabot> 9.3.0.4-12.mga5
+ Revision: 740116
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 9.3.0.4-11.mga5
+ Revision: 689039
- Mageia 5 Mass Rebuild

* Tue Oct 22 2013 umeabot <umeabot> 9.3.0.4-10.mga4
+ Revision: 544943
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 dmorgan <dmorgan> 9.3.0.4-9.mga4
+ Revision: 500501
- Add alias with dom classifier

* Tue Oct 15 2013 dmorgan <dmorgan> 9.3.0.4-8.mga4
+ Revision: 500426
- Add licences

* Mon Jan 14 2013 umeabot <umeabot> 9.3.0.4-2.mga3
+ Revision: 381757
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Sep 09 2012 dmorgan <dmorgan> 9.3.0.4-1.mga3
+ Revision: 291400
- New version

* Mon Nov 07 2011 dmorgan <dmorgan> 0:6.5.5-2.mga2
+ Revision: 164580
- Clean spec file

  + gil <gil>
    - added maven2 pom

* Sun Jan 16 2011 ahmad <ahmad> 0:6.5.5-1.2.5.mga1
+ Revision: 20381
- imported package saxon


* Wed Jan 02 2008 Olivier Blin <oblin@mandriva.com> 0:6.5.5-1.2.5mdv2009.0
+ Revision: 140756
- restore BuildRoot

* Tue Dec 18 2007 David Walluck <walluck@mandriva.org> 0:6.5.5-1.2.5mdv2008.1
+ Revision: 132716
- don't own alternative link

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:6.5.5-1.2.4mdv2008.1
+ Revision: 121019
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:6.5.5-1.2.3mdv2008.0
+ Revision: 87357
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill file require on update-alternatives

* Wed Jul 18 2007 Anssi Hannula <anssi@mandriva.org> 0:6.5.5-1.2.2mdv2008.0
+ Revision: 53209
- use xml-commons-jaxp-1.3-apis and xml-commons-resolver12 explicitely
  instead of the generic xml-commons-apis and xml-commons-resolver which
  are provided by multiple packages (see bug #31473)

* Sun Apr 22 2007 David Walluck <walluck@mandriva.org> 0:6.5.5-1.2.1mdv2008.0
+ Revision: 17108
- Import saxon



* Mon Mar 12 2007 David Walluck <walluck@mandriva.org> 0:6.5.5-1.2.1mdv2008.0
- release

* Sun Mar 11 2007 Vivek Lakshmanan <vivekl@redhat.com> - 0:6.5.5-1jpp.2.fc7
- First build for Fedora
- Resolves: #227114 (Missing BR on ant - Thanks mcepl)

* Wed Feb 14 2007 Deepak Bhole <dbhole@redhat.com> - 0:6.5.5-1jpp.1
- Update to 6.5.5
- Fix per Fedora guidelines

* Tue May 02 2006 Ralph Apel <r.apel@r-apel.de> - 0:6.5.3-4jpp
- First JPP-1.7 release

* Fri Sep 03 2004 Fernando Nasser <fnasser@redhat.com> - 0:6.5.3-3jpp
- Rebuilt with Ant 1.6.2

* Mon Jul 19 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:6.5.3-2jpp
- Apply two patches for known limitations from
  http://saxon.sourceforge.net/saxon6.5.3/limitations.html
- Make the command line script use xml-commons-resolver if it's available.
- Include man page for command line script.
- Add patch to fix command line option handling and document missing options.
- New style versionless javadoc dir symlinking.
- Crosslink with local J2SE javadocs.
- Add missing jdom-javadoc build dependency.

* Sun Aug 31 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:6.5.3-1jpp
- Update to 6.5.3.
- Crosslink with local xml-commons-apis and fop javadocs.

* Tue Jun  3 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:6.5.2-7jpp
- Non-versioned javadoc symlinking.
- Include Main-Class attribute in saxon.jar.
- Own (ghost) %%{_javadir}/jaxp_transform_impl.jar.
- Remove alternatives in preun instead of postun.

* Thu Apr 17 2003 Ville Skyttä <ville.skytta at iki.fi> - 6.5.2-6jpp
- Rebuild for JPackage 1.5.
- Split shell script to -scripts subpackage.
- Use non-versioned jar in jaxp_transform_impl alternative, and don't remove
  it on upgrade.
- Spec file cleanups.

* Thu Jul 25 2002 Ville Skyttä <ville.skytta at iki.fi> 6.5.2-5jpp
- Fix shell script (again).
- Rebuild with -Dbuild.compiler=modern (saxon-fop won't build with jikes).

* Fri Jul 19 2002 Ville Skyttä <ville.skytta at iki.fi> 6.5.2-4jpp
- First public JPackage release.
- Compile with build.xml by yours truly.
- AElfred no more provides jaxp_parser_impl; it's SAX only, no DOM.
- Fix shell script.

* Mon Jul  1 2002 Ville Skyttä <ville.skytta at iki.fi> 6.5.2-3jpp
- Provides jaxp_parser_impl.
- Requires xml-commons-apis.

* Sun Jun 30 2002 Ville Skyttä <ville.skytta at iki.fi> 6.5.2-2jpp
- Use sed instead of bash 2 extension when symlinking jars.
- Provides jaxp_transform_impl.

* Sat May 11 2002 Ville Skyttä <ville.skytta at iki.fi> 6.5.2-1jpp
- First JPackage release.
- Provides jaxp_parser2 though there's no DOM implementation in this AElfred.
